@@ -1,12 +1,3 @@
-#  File R/ergmm.R in package latentnet, part of the Statnet suite
-#  of packages for network analysis, http://statnet.org .
-#
-#  This software is distributed under the GPL-3 license.  It is free,
-#  open source, and has the attribution requirements (GPL Section 7) at
-#  http://statnet.org/attribution
-#
-#  Copyright 2003-2014 Statnet Commons
-#######################################################################
 ergmm <- function(formula,response=NULL,family="Bernoulli",fam.par=NULL,
                   control=ergmm.control(),
                   user.start=list(),
@@ -88,7 +79,7 @@ ergmm <- function(formula,response=NULL,family="Bernoulli",fam.par=NULL,
             burnin.state<-sapply(1:burnin.control[["threads"]],
                                  function(thread) burnin.sample[[thread]][[burnin.size]],
                                  simplify=FALSE)
-            burnin.sample<-stack.ergmm.par.list.list(burnin.sample)
+            burnin.sample<-.stack.ergmm.par.list.list(burnin.sample)
           }
           if(control[["store.burnin"]]) burnin.samples[[length(burnin.samples)+1]]<-burnin.sample
           if(control[["pilot.runs"]]){
@@ -116,7 +107,7 @@ ergmm <- function(formula,response=NULL,family="Bernoulli",fam.par=NULL,
                                     prior.l=list(prior),
                                     control.l=list(control),
                                     sample.size.l=list(ceiling(control[["sample.size"]]/control[["threads"]])))
-      mcmc.out[["sample"]] <- stack.ergmm.par.list.list(mcmc.out[["sample"]])
+      mcmc.out[["sample"]] <- .stack.ergmm.par.list.list(mcmc.out[["sample"]])
     }
     if(control[["verbose"]]) cat("Finished.\n")
   }
