@@ -1,12 +1,3 @@
-#  File R/ergmm.par.R in package latentnet, part of the Statnet suite
-#  of packages for network analysis, http://statnet.org .
-#
-#  This software is distributed under the GPL-3 license.  It is free,
-#  open source, and has the attribution requirements (GPL Section 7) at
-#  http://statnet.org/attribution
-#
-#  Copyright 2003-2014 Statnet Commons
-#######################################################################
 # Utilities for dealing with MCMC output produced by *.MCMC.C functions.
 
 ERGMM.PAR_VAR_NAMES<-c("beta","Z","sender","receiver","sociality",
@@ -82,7 +73,7 @@ length.ergmm.par.list<-function(x){
   }
 }
 
-stack.ergmm.par.list.list<-function(x,...){
+.stack.ergmm.par.list.list<-function(x,...){
   extraneous.argcheck(...)
   mcmcsample<-list()
 
