@@ -1,12 +1,3 @@
-/*  File src/ergmm_sampler.c in package latentnet, part of the Statnet suite
- *  of packages for network analysis, http://statnet.org .
- *
- *  This software is distributed under the GPL-3 license.  It is free,
- *  open source, and has the attribution requirements (GPL Section 7) at
- *  http://statnet.org/attribution
- *
- *  Copyright 2003-2014 Statnet Commons
- */
 /****************************************************************************/
 /* Top-level functions for sampling from an ERGMM's posterior distribution. */
 /****************************************************************************/
@@ -188,7 +179,7 @@ void ERGMM_MCMC_wrapper(int *sample_size,
 		  *dir,iY,dY,
 		  *family-1,
 		  iconsts,dconsts,
-		  latent_eff ? *latent_eff-1 : 1000,
+		  *latent_eff ? *latent_eff-1 : 1000,
 
 		  X,
 
